==> tify-0.25.3.tgz: package/doc/user-guide.de.md <==
# TIFY Kurzanleitung

## Einführung

TIFY ist ein schlanker IIIF-Dokumentenbetrachter, der für Mobilgeräte optimiert wurde und eine schnelle und leicht zu bedienende Oberfläche bietet.

IIIF steht für »International Image Interoperability Framework« und definiert verschiedene <acronym title="application programming interface">API</acronym>s, mit denen Bilddateien zusammen mit Metadaten für Präsentation und Struktur beschrieben und verteilt werden können. Dadurch können Büchern, Zeitungen, Handschriften, Karten, Schriftrollen und Archivmaterial weltweit zwischen Intitutionen und Repositorien mit geringem Aufwand geteilt werden. Diese Bilder und Metadaten lassen sich mit jeder IIIF-kompatiblen Anwendung verarbeiten und anzeigen. [Erfahren Sie mehr über IIIF.](http://iiif.io/about/)

## Anzeige mehrerer Seiten

Beliebige Seiten können nebeneinander dargestellt werden.

Öffnen Sie dazu die Ansicht »Seiten« und wählen Sie mehrere Seiten aus, indem Sie diese mit gedrückter <kbd>Strg</kbd>-Taste anklicken &ndash; oder länger berühren, wenn Sie einen Touchscreen verwenden.

## Tastenbelegung

TIFY kann vollständig mit der Tastatur bedient werden.

### Ansicht

| Aktion | Taste |
| --- | :---: |
| Volltext (wenn verfügbar) | <kbd>1</kbd> |
| Seiten | <kbd>2</kbd> |
| Inhalt (wenn verfügbar) | <kbd>3</kbd> |
| Info | <kbd>4</kbd> |
| Export | <kbd>5</kbd> |
| Hilfe | <kbd>6</kbd> |
| Scan | <kbd>Rücktaste</kbd> |
| Vollbild | <kbd>F</kbd> |

### Blättern

| Aktion | Taste |
| --- | :---: |
| Vorige Seite | <kbd>Q</kbd> oder <kbd>,</kbd> |
| Nächste Seite | <kbd>E</kbd> oder <kbd>.</kbd> |
| Erste Seite | <kbd>&#8679;Q</kbd> |
| Letzte Seite | <kbd>&#8679;E</kbd> |
| Zu Seite springen | <kbd>X</kbd> |
| Doppelseite umschalten | <kbd>B</kbd> |

### Scan

| Aktion | Taste |
| --- | :---: |
| Bewegen | <kbd>W</kbd> <kbd>S</kbd> <kbd>A</kbd> <kbd>D</kbd> |
| Vergrößern | <kbd>&#8679;W</kbd> oder <kbd>+</kbd> |
| Verkleinern | <kbd>&#8679;S</kbd> oder <kbd>-</kbd> |
| Drehen (90 Grad im Uhrzeigersinn) | <kbd>R</kbd> |
| Filter umschalten | <kbd>I</kbd> |
| Position und Vergrößerung zurücksetzen | <kbd>0</kbd> |
| Drehung zurücksetzen | <kbd>&#8679;</kbd> + <kbd>R</kbd> |
| Filter zurücksetzen| <kbd>&#8679;</kbd> + <kbd>I</kbd> |
| Alles zurücksetzen | <kbd>&#8679;</kbd> + <kbd>0</kbd> |
| Vollbildschirm umschalten | <kbd>U</kbd> |

==> tify-0.29.2.tgz: package/doc/user-guide.de.md <==
# TIFY Kurzanleitung

## Einführung

TIFY ist ein schlanker IIIF-Dokumentenbetrachter, der für Mobilgeräte optimiert wurde und eine schnelle und leicht zu bedienende Oberfläche bietet.

IIIF steht für »International Image Interoperability Framework« und definiert verschiedene <acronym title="application programming interface">API</acronym>s, mit denen Bilddateien zusammen mit Metadaten für Präsentation und Struktur beschrieben und verteilt werden können. Dadurch können Büchern, Zeitungen, Handschriften, Karten, Schriftrollen und Archivmaterial weltweit zwischen Intitutionen und Repositorien mit geringem Aufwand geteilt werden. Diese Bilder und Metadaten lassen sich mit jeder IIIF-kompatiblen Anwendung verarbeiten und anzeigen. [Erfahren Sie mehr über IIIF.](http://iiif.io/about/)

## Anzeige mehrerer Seiten

Beliebige Seiten können nebeneinander dargestellt werden.

Öffnen Sie dazu die Ansicht »Seiten« und wählen Sie mehrere Seiten aus, indem Sie diese mit gedrückter <kbd>Strg</kbd>-Taste anklicken &ndash; oder länger berühren, wenn Sie einen Touchscreen verwenden.

## Tastenbelegung

TIFY kann vollständig mit der Tastatur bedient werden.

### Ansicht

| Aktion | Taste |
| --- | :---: |
| Volltext (wenn verfügbar) | <kbd>1</kbd> |
| Seiten | <kbd>2</kbd> |
| Inhalt (wenn verfügbar) | <kbd>3</kbd> |
| Info | <kbd>4</kbd> |
| Export | <kbd>5</kbd> |
| Sammlung (wenn verfügbar) | <kbd>6</kbd> |
| Hilfe | <kbd>7</kbd> |
| Scan | <kbd>Rücktaste</kbd> |
| Vollbild | <kbd>F</kbd> |

### Blättern

| Aktion | Taste |
| --- | :---: |
| Vorige Seite | <kbd>Q</kbd> oder <kbd>,</kbd> |
| Nächste Seite | <kbd>E</kbd> oder <kbd>.</kbd> |
| Erste Seite | <kbd>&#8679;Q</kbd> |
| Letzte Seite | <kbd>&#8679;E</kbd> |
| Zu Seite springen | <kbd>X</kbd> |
| Doppelseite umschalten | <kbd>B</kbd> |

### Scan

| Aktion | Taste |
| --- | :---: |
| Bewegen | <kbd>W</kbd> <kbd>S</kbd> <kbd>A</kbd> <kbd>D</kbd> |
| Vergrößern | <kbd>&#8679;W</kbd> oder <kbd>+</kbd> |
| Verkleinern | <kbd>&#8679;S</kbd> oder <kbd>-</kbd> |
| Drehen (90 Grad im Uhrzeigersinn) | <kbd>R</kbd> |
| Filter umschalten | <kbd>I</kbd> |
| Position und Vergrößerung zurücksetzen | <kbd>0</kbd> |
| Drehung zurücksetzen | <kbd>&#8679;</kbd> + <kbd>R</kbd> |
| Filter zurücksetzen| <kbd>&#8679;</kbd> + <kbd>I</kbd> |
| Alles zurücksetzen | <kbd>&#8679;</kbd> + <kbd>0</kbd> |
| Vollbildschirm umschalten | <kbd>U</kbd> |
